@@ -168,7 +168,7 @@ print.bal.tab <- function(x, imbalanced.only = "as.is", un = "as.is", disp.bal.t
         
         cat(underline("Balance Measures") %+% "\n")
         if (all(!keep.row)) cat(italic("All covariates are balanced.") %+% "\n")
-        else print.data.frame_(round_df_char(balance[keep.row, keep.col, drop = FALSE], digits))
+        else print.data.frame_(round_df_char(balance[keep.row, keep.col, drop = FALSE], digits, na_vals = "."))
         cat("\n")
     }
     
@@ -180,18 +180,17 @@ print.bal.tab <- function(x, imbalanced.only = "as.is", un = "as.is", disp.bal.t
         }
         if (is_not_null(maximbal[[s]])) {
             cat(underline(paste("Variable with the greatest", STATS[[s]]$variable_with_the_greatest)) %+% "\n")
-            print.data.frame_(round_df_char(maximbal[[s]], digits), row.names = FALSE)
+            print.data.frame_(round_df_char(maximbal[[s]], digits, na_vals = "."), row.names = FALSE)
             cat("\n")
         }
     }
     
     if (is_not_null(nn)) {
-        for (i in seq_len(NROW(nn))) {
-            if (all(nn[i,] == 0)) {
-                nn <- nn[-i, , drop = FALSE]
-                attr(nn, "ss.type") <- attr(nn, "ss.type")[-i]
-            }
-        }
+        
+        drop.nn <- rowSums(nn) == 0
+        ss.type <- attr(nn, "ss.type")[!drop.nn]
+        nn <- nn[!drop.nn, , drop = FALSE]
+        
         if (all(c("Matched (ESS)", "Matched (Unweighted)") %in% rownames(nn)) && 
             all(check_if_zero(nn["Matched (ESS)",] - nn["Matched (Unweighted)",]))) {
             nn <- nn[rownames(nn)!="Matched (Unweighted)", , drop = FALSE]
@@ -199,8 +198,8 @@ print.bal.tab <- function(x, imbalanced.only = "as.is", un = "as.is", disp.bal.t
         }
         cat(underline(attr(nn, "tag")) %+% "\n")
         print.warning <- FALSE
-        if (length(attr(nn, "ss.type")) > 1 && nunique.gt(attr(nn, "ss.type")[-1], 1)) {
-            ess <- ifelse(attr(nn, "ss.type") == "ess", "*", "")
+        if (length(ss.type) > 1 && nunique.gt(ss.type[-1], 1)) {
+            ess <- ifelse(ss.type == "ess", "*", "")
             nn <- setNames(cbind(nn, ess), c(names(nn), ""))
             print.warning <- TRUE
         }
@@ -444,14 +443,14 @@ print.bal.tab.cluster <- function(x, imbalanced.only = "as.is", un = "as.is", di
         
         if (p.ops$disp.bal.tab) {
             cat(underline("Balance summary across all clusters") %+% "\n")
-            print.data.frame_(round_df_char(c.balance.summary[, s.keep.col, drop = FALSE], digits))
+            print.data.frame_(round_df_char(c.balance.summary[, s.keep.col, drop = FALSE], digits, na_vals = "."))
             cat("\n")
         }
         
         if (is_not_null(nn)) {
-            for (i in rownames(nn)) {
-                if (all(nn[i,] == 0)) nn <- nn[rownames(nn)!=i,]
-            }
+            drop.nn <- rowSums(nn) == 0
+            ss.type <- attr(nn, "ss.type")[!drop.nn]
+            nn <- nn[!drop.nn, , drop = FALSE]
             if (all(c("Matched (ESS)", "Matched (Unweighted)") %in% rownames(nn)) && 
                 all(check_if_zero(nn["Matched (ESS)",] - nn["Matched (Unweighted)",]))) {
                 nn <- nn[rownames(nn)!="Matched (Unweighted)", , drop = FALSE]
@@ -459,8 +458,8 @@ print.bal.tab.cluster <- function(x, imbalanced.only = "as.is", un = "as.is", di
             }
             cat(underline(attr(nn, "tag")) %+% "\n")
             print.warning <- FALSE
-            if (length(attr(nn, "ss.type")) > 1 && nunique.gt(attr(nn, "ss.type")[-1], 1)) {
-                ess <- ifelse(attr(nn, "ss.type") == "ess", "*", "")
+            if (length(ss.type) > 1 && nunique.gt(ss.type[-1], 1)) {
+                ess <- ifelse(ss.type == "ess", "*", "")
                 nn <- setNames(cbind(nn, ess), c(names(nn), ""))
                 print.warning <- TRUE
             }
@@ -700,14 +699,14 @@ print.bal.tab.imp <- function(x, imbalanced.only = "as.is", un = "as.is", disp.b
         
         if (p.ops$disp.bal.tab) {
             cat(underline("Balance summary across all imputations") %+% "\n")
-            print.data.frame_(round_df_char(i.balance.summary[, s.keep.col, drop = FALSE], digits))
+            print.data.frame_(round_df_char(i.balance.summary[, s.keep.col, drop = FALSE], digits, na_vals = "."))
             cat("\n")
         }
         
         if (is_not_null(nn)) {
-            for (i in rownames(nn)) {
-                if (all(nn[i,] == 0)) nn <- nn[rownames(nn)!=i,]
-            }
+            drop.nn <- rowSums(nn) == 0
+            ss.type <- attr(nn, "ss.type")[!drop.nn]
+            nn <- nn[!drop.nn, , drop = FALSE]
             if (all(c("Matched (ESS)", "Matched (Unweighted)") %in% rownames(nn)) && 
                 all(check_if_zero(nn["Matched (ESS)",] - nn["Matched (Unweighted)",]))) {
                 nn <- nn[rownames(nn)!="Matched (Unweighted)", , drop = FALSE]
@@ -715,8 +714,8 @@ print.bal.tab.imp <- function(x, imbalanced.only = "as.is", un = "as.is", disp.b
             }
             cat(underline(attr(nn, "tag")) %+% "\n")
             print.warning <- FALSE
-            if (length(attr(nn, "ss.type")) > 1 && nunique.gt(attr(nn, "ss.type")[-1], 1)) {
-                ess <- ifelse(attr(nn, "ss.type") == "ess", "*", "")
+            if (length(ss.type) > 1 && nunique.gt(ss.type[-1], 1)) {
+                ess <- ifelse(ss.type == "ess", "*", "")
                 nn <- setNames(cbind(nn, ess), c(names(nn), ""))
                 print.warning <- TRUE
             }
@@ -987,16 +986,15 @@ print.bal.tab.multi <- function(x, imbalanced.only = "as.is", un = "as.is", disp
         if (p.ops$disp.bal.tab) {
             cat(underline("Balance summary across all treatment pairs") %+% "\n")
             if (all(!keep.row)) cat(italic("All covariates are balanced.") %+% "\n")
-            else print.data.frame_(round_df_char(m.balance.summary[keep.row, s.keep.col, drop = FALSE], digits))
+            else print.data.frame_(round_df_char(m.balance.summary[keep.row, s.keep.col, drop = FALSE], digits, na_vals = "."))
             cat("\n")
         }
         
         if (is_not_null(nn)) {
             tag <- attr(nn, "tag")
-            ss.type <- attr(nn, "ss.type")
-            for (i in rownames(nn)) {
-                if (all(nn[i,] == 0)) nn <- nn[rownames(nn)!=i,]
-            }
+            drop.nn <- rowSums(nn) == 0
+            ss.type <- attr(nn, "ss.type")[!drop.nn]
+            nn <- nn[!drop.nn, , drop = FALSE]
             if (all(c("Matched (ESS)", "Matched (Unweighted)") %in% rownames(nn)) && 
                 all(check_if_zero(nn["Matched (ESS)",] - nn["Matched (Unweighted)",]))) {
                 nn <- nn[rownames(nn)!="Matched (Unweighted)", , drop = FALSE]
@@ -1250,7 +1248,7 @@ print.bal.tab.msm <- function(x, imbalanced.only = "as.is", un = "as.is", disp.b
         if (p.ops$disp.bal.tab) {
             cat(underline("Balance summary across all time points") %+% "\n")
             if (all(!keep.row)) cat(italic("All covariates are balanced.") %+% "\n")
-            else print.data.frame_(round_df_char(msm.balance.summary[keep.row, s.keep.col, drop = FALSE], digits))
+            else print.data.frame_(round_df_char(msm.balance.summary[keep.row, s.keep.col, drop = FALSE], digits, na_vals = "."))
             cat("\n")
         }
         
@@ -1260,16 +1258,16 @@ print.bal.tab.msm <- function(x, imbalanced.only = "as.is", un = "as.is", disp.b
             
             for (ti in seq_along(nn)) {
                 cat(" - " %+% italic("Time " %+% as.character(ti)) %+% "\n")
-                for (i in rownames(nn[[ti]])) {
-                    if (all(nn[[ti]][i,] == 0)) nn[[ti]] <- nn[[ti]][rownames(nn[[ti]])!=i,]
-                }
+                drop.nn <- rowSums(nn[[ti]]) == 0
+                ss.type <- attr(nn[[ti]], "ss.type")[!drop.nn]
+                nn[[ti]] <- nn[[ti]][!drop.nn, , drop = FALSE]
                 if (all(c("Matched (ESS)", "Matched (Unweighted)") %in% rownames(nn[[ti]])) && 
                     all(check_if_zero(nn[[ti]]["Matched (ESS)",] - nn[[ti]]["Matched (Unweighted)",]))) {
                     nn[[ti]] <- nn[[ti]][rownames(nn[[ti]])!="Matched (Unweighted)", , drop = FALSE]
                     rownames(nn[[ti]])[rownames(nn[[ti]]) == "Matched (ESS)"] <- "Matched"
                 }
-                if (length(attr(nn[[ti]], "ss.type")) > 1 && nunique.gt(attr(nn[[ti]], "ss.type")[-1], 1)) {
-                    ess <- ifelse(attr(nn[[ti]], "ss.type") == "ess", "*", "")
+                if (length(ss.type) > 1 && nunique.gt(ss.type[-1], 1)) {
+                    ess <- ifelse(ss.type == "ess", "*", "")
                     nn[[ti]] <- setNames(cbind(nn[[ti]], ess), c(names(nn[[ti]]), ""))
                     print.warning <- TRUE
                 }
@@ -1450,7 +1448,7 @@ print.bal.tab.subclass <- function(x, imbalanced.only = "as.is", un = "as.is", d
                 
                 cat("\n - - - " %+% italic("Subclass " %+% as.character(i)) %+% " - - - \n")
                 if (all(!s.keep.row)) cat(italic("All covariates are balanced.") %+% "\n")
-                else print.data.frame_(round_df_char(s.balance[[i]][s.keep.row, s.keep.col, drop = FALSE], digits))
+                else print.data.frame_(round_df_char(s.balance[[i]][s.keep.row, s.keep.col, drop = FALSE], digits, na_vals = "."))
             }
             cat("\n")
         }
@@ -1482,7 +1480,7 @@ print.bal.tab.subclass <- function(x, imbalanced.only = "as.is", un = "as.is", d
             
             cat(underline("Balance measures across subclasses") %+% "\n")
             if (all(!a.s.keep.row)) cat(italic("All covariates are balanced.") %+% "\n")
-            else print.data.frame_(round_df_char(b.a.subclass[a.s.keep.row, a.s.keep.col, drop = FALSE], digits))
+            else print.data.frame_(round_df_char(b.a.subclass[a.s.keep.row, a.s.keep.col, drop = FALSE], digits, na_vals = "."))
             cat("\n")
         }
     }
@@ -1495,7 +1493,7 @@ print.bal.tab.subclass <- function(x, imbalanced.only = "as.is", un = "as.is", d
         }
         if (is_not_null(maximbal[[s]])) {
             cat(underline(paste("Variable with the greatest", STATS[[s]]$variable_with_the_greatest, "across subclasses")) %+% "\n")
-            print.data.frame_(round_df_char(maximbal[[s]], digits), row.names = FALSE)
+            print.data.frame_(round_df_char(maximbal[[s]], digits, na_vals = "."), row.names = FALSE)
             cat("\n")
         }
     }
